EXPORTS
	??0CMsgAsyncItemSaver@@QAE@XZ @ 1 NONAME ; public: __thiscall CMsgAsyncItemSaver::CMsgAsyncItemSaver(void)
	??0CMsgBioControl@@QAE@AAVMMsgBioControlObserver@@PAVCMsvSession@@JW4TMsgBioMode@@ABV?$TBuf@$0BAA@@@@Z @ 2 NONAME ; public: __thiscall CMsgBioControl::CMsgBioControl(class MMsgBioControlObserver &,class CMsvSession *,long,enum TMsgBioMode,class TBuf<256> const &)
	??1CMsgAsyncItemSaver@@UAE@XZ @ 3 NONAME ; public: virtual __thiscall CMsgAsyncItemSaver::~CMsgAsyncItemSaver(void)
	??1CMsgBioBodyControl@@UAE@XZ @ 4 NONAME ; public: virtual __thiscall CMsgBioBodyControl::~CMsgBioBodyControl(void)
	??1CMsgBioControl@@UAE@XZ @ 5 NONAME ; public: virtual __thiscall CMsgBioControl::~CMsgBioControl(void)
	??1CMsgBioControlFactory@@UAE@XZ @ 6 NONAME ; public: virtual __thiscall CMsgBioControlFactory::~CMsgBioControlFactory(void)
	??1CMsgDetailWindow@@UAE@XZ @ 7 NONAME ; public: virtual __thiscall CMsgDetailWindow::~CMsgDetailWindow(void)
	??1CMsgNameValue@@UAE@XZ @ 8 NONAME ; public: virtual __thiscall CMsgNameValue::~CMsgNameValue(void)
	?AddMenuItemL@CMsgBioControl@@IAEXAAVCEikMenuPane@@HHH@Z @ 9 NONAME ; protected: void __thiscall CMsgBioControl::AddMenuItemL(class CEikMenuPane &,int,int,int)
	?BioControl@CMsgBioBodyControl@@QAEAAVCMsgBioControl@@XZ @ 10 NONAME ; public: class CMsgBioControl & __thiscall CMsgBioBodyControl::BioControl(void)
	?CheckIP@MsgBioUtils@@SAHABVTDesC16@@@Z @ 11 NONAME ; public: static int __cdecl MsgBioUtils::CheckIP(class TDesC16 const &)
	?CheckURL@MsgBioUtils@@SAHABVTDesC16@@@Z @ 12 NONAME ; public: static int __cdecl MsgBioUtils::CheckURL(class TDesC16 const &)
	?ClipboardL@CMsgBioBodyControl@@UAEXW4TMsgClipboardFunc@@@Z @ 13 NONAME ; public: virtual void __thiscall CMsgBioBodyControl::ClipboardL(enum TMsgClipboardFunc)
	?ConfirmationNoteL@MsgBioUtils@@SAXABVTDesC16@@@Z @ 14 NONAME ; public: static void __cdecl MsgBioUtils::ConfirmationNoteL(class TDesC16 const &)
	?ConfirmationNoteL@MsgBioUtils@@SAXH@Z @ 15 NONAME ; public: static void __cdecl MsgBioUtils::ConfirmationNoteL(int)
	?ConfirmationQueryL@CMsgBioControl@@SAHABVTDesC16@@@Z @ 16 NONAME ; public: static int __cdecl CMsgBioControl::ConfirmationQueryL(class TDesC16 const &)
	?ConfirmationQueryL@CMsgBioControl@@SAHH@Z @ 17 NONAME ; public: static int __cdecl CMsgBioControl::ConfirmationQueryL(int)
	?Control@CMsgDetailWindow@@QBEAAVCRichBio@@XZ @ 18 NONAME ; public: class CRichBio & __thiscall CMsgDetailWindow::Control(void)const 
	?CreateControlL@CMsgBioControlFactory@@QAEPAVCMsgBioControl@@AAVMMsgBioControlObserver@@ABVTUid@@W4TMsgBioMode@@ABV?$TBuf@$0BAA@@@@Z @ 19 NONAME ; public: class CMsgBioControl * __thiscall CMsgBioControlFactory::CreateControlL(class MMsgBioControlObserver &,class TUid const &,enum TMsgBioMode,class TBuf<256> const &)
	?CreateControlL@CMsgBioControlFactory@@QAEPAVCMsgBioControl@@AAVMMsgBioControlObserver@@ABVTUid@@W4TMsgBioMode@@JPAVCMsvSession@@@Z @ 20 NONAME ; public: class CMsgBioControl * __thiscall CMsgBioControlFactory::CreateControlL(class MMsgBioControlObserver &,class TUid const &,enum TMsgBioMode,long,class CMsvSession *)
	?CurrentLineRect@CMsgBioBodyControl@@UAE?AVTRect@@XZ @ 21 NONAME ; public: virtual class TRect  __thiscall CMsgBioBodyControl::CurrentLineRect(void)
	?EditL@CMsgBioBodyControl@@UAEXW4TMsgEditFunc@@@Z @ 22 NONAME ; public: virtual void __thiscall CMsgBioBodyControl::EditL(enum TMsgEditFunc)
	?EditPermission@CMsgBioBodyControl@@UBEKXZ @ 23 NONAME ; public: virtual unsigned long __thiscall CMsgBioBodyControl::EditPermission(void)const 
	?ErrorNoteL@MsgBioUtils@@SAXABVTDesC16@@@Z @ 24 NONAME ; public: static void __cdecl MsgBioUtils::ErrorNoteL(class TDesC16 const &)
	?ErrorNoteL@MsgBioUtils@@SAXH@Z @ 25 NONAME ; public: static void __cdecl MsgBioUtils::ErrorNoteL(int)
	?FileName@CMsgBioControl@@IBEABV?$TBuf@$0BAA@@@XZ @ 26 NONAME ; protected: class TBuf<256> const & __thiscall CMsgBioControl::FileName(void)const 
	?HandleBaseControlEventRequestL@CMsgBioBodyControl@@UAEHW4TMsgBioControlEventRequest@@H@Z @ 27 NONAME ; public: virtual int __thiscall CMsgBioBodyControl::HandleBaseControlEventRequestL(enum TMsgBioControlEventRequest,int)
	?HandleBioCommandL@CMsgBioBodyControl@@QAEHH@Z @ 28 NONAME ; public: int __thiscall CMsgBioBodyControl::HandleBioCommandL(int)
	?HeaderTextL@CMsgBioBodyControl@@QBEPAVHBufC16@@XZ @ 29 NONAME ; public: class HBufC16 * __thiscall CMsgBioBodyControl::HeaderTextL(void)const 
	?Hide@CMsgDetailWindow@@QAEXXZ @ 30 NONAME ; public: void __thiscall CMsgDetailWindow::Hide(void)
	?IncrementNameL@MsgBioUtils@@SAXAAVTDes16@@@Z @ 31 NONAME ; public: static void __cdecl MsgBioUtils::IncrementNameL(class TDes16 &)
	?InformationNoteL@MsgBioUtils@@SAXABVTDesC16@@@Z @ 32 NONAME ; public: static void __cdecl MsgBioUtils::InformationNoteL(class TDesC16 const &)
	?InformationNoteL@MsgBioUtils@@SAXH@Z @ 33 NONAME ; public: static void __cdecl MsgBioUtils::InformationNoteL(int)
	?IsCursorLocation@CMsgBioBodyControl@@UBEHW4TMsgCursorLocation@@@Z @ 34 NONAME ; public: virtual int __thiscall CMsgBioBodyControl::IsCursorLocation(enum TMsgCursorLocation)const 
	?IsCursorLocation@CMsgBioControl@@UBEHW4TMsgCursorLocation@@@Z @ 35 NONAME ; public: virtual int __thiscall CMsgBioControl::IsCursorLocation(enum TMsgCursorLocation)const 
	?IsEditor@CMsgBioControl@@IBEHXZ @ 36 NONAME ; protected: int __thiscall CMsgBioControl::IsEditor(void)const 
	?IsFileBased@CMsgBioControl@@IBEHXZ @ 37 NONAME ; protected: int __thiscall CMsgBioControl::IsFileBased(void)const 
	?IsFocusChangePossible@CMsgBioBodyControl@@UBEHW4TMsgFocusDirection@@@Z @ 38 NONAME ; public: virtual int __thiscall CMsgBioBodyControl::IsFocusChangePossible(enum TMsgFocusDirection)const 
	?LoadResourceL@CMsgBioControl@@IAEXABVTDesC16@@0@Z @ 39 NONAME ; protected: void __thiscall CMsgBioControl::LoadResourceL(class TDesC16 const &,class TDesC16 const &)
	?LoadResourceL@CMsgBioControl@@IAEXABVTDesC16@@@Z @ 40 NONAME ; protected: void __thiscall CMsgBioControl::LoadResourceL(class TDesC16 const &)
	?LoadStandardBioResourceL@CMsgBioControl@@IAEXXZ @ 41 NONAME ; protected: void __thiscall CMsgBioControl::LoadStandardBioResourceL(void)
	?MsvSession@CMsgBioControl@@IBEAAVCMsvSession@@XZ @ 42 NONAME ; protected: class CMsvSession & __thiscall CMsgBioControl::MsvSession(void)const 
	?Name@CMsgNameValue@@QBEABVTDesC16@@XZ @ 43 NONAME ; public: class TDesC16 const & __thiscall CMsgNameValue::Name(void)const 
	?NewL@CMsgBioBodyControl@@SAPAV1@AAVMMsgBioControlObserver@@ABVTUid@@JW4TMsgBioMode@@AAVCMsvSession@@@Z @ 44 NONAME ; public: static class CMsgBioBodyControl * __cdecl CMsgBioBodyControl::NewL(class MMsgBioControlObserver &,class TUid const &,long,enum TMsgBioMode,class CMsvSession &)
	?NewL@CMsgBioControlFactory@@SAPAV1@XZ @ 45 NONAME ; public: static class CMsgBioControlFactory * __cdecl CMsgBioControlFactory::NewL(void)
	?NewL@CMsgDetailWindow@@SAPAV1@XZ @ 46 NONAME ; public: static class CMsgDetailWindow * __cdecl CMsgDetailWindow::NewL(void)
	?NewL@CMsgNameValue@@SAPAV1@ABVTDesC16@@0@Z @ 47 NONAME ; public: static class CMsgNameValue * __cdecl CMsgNameValue::NewL(class TDesC16 const &,class TDesC16 const &)
	?NewL@CMsgNameValue@@SAPAV1@PAVHBufC16@@0@Z @ 48 NONAME ; public: static class CMsgNameValue * __cdecl CMsgNameValue::NewL(class HBufC16 *,class HBufC16 *)
	?NewLC@CMsgNameValue@@SAPAV1@ABVTDesC16@@0@Z @ 49 NONAME ; public: static class CMsgNameValue * __cdecl CMsgNameValue::NewLC(class TDesC16 const &,class TDesC16 const &)
	?NotifyEditorViewL@CMsgBioControl@@IAEHW4TMsgBioControlEventRequest@@H@Z @ 50 NONAME ; protected: int __thiscall CMsgBioControl::NotifyEditorViewL(enum TMsgBioControlEventRequest,int)
	?OptionMenuPermissionsL@CMsgBioControl@@UBEKXZ @ 51 NONAME ; public: virtual unsigned long __thiscall CMsgBioControl::OptionMenuPermissionsL(void)const 
	?SetAndGetSizeL@CMsgBioBodyControl@@UAEXAAVTSize@@@Z @ 52 NONAME ; public: virtual void __thiscall CMsgBioBodyControl::SetAndGetSizeL(class TSize &)
	?SetControlL@CMsgDetailWindow@@QAEXPAVCRichBio@@@Z @ 53 NONAME ; public: void __thiscall CMsgDetailWindow::SetControlL(class CRichBio *)
	?SetMenuCommandSetL@CMsgBioBodyControl@@QAEXAAVCEikMenuPane@@@Z @ 54 NONAME ; public: void __thiscall CMsgBioBodyControl::SetMenuCommandSetL(class CEikMenuPane &)
	?Show@CMsgDetailWindow@@QAEXXZ @ 55 NONAME ; public: void __thiscall CMsgDetailWindow::Show(void)
	?StartOperation@CMsgAsyncItemSaver@@QAEXPAVMMsgAsyncItemSaver@@@Z @ 56 NONAME ; public: void __thiscall CMsgAsyncItemSaver::StartOperation(class MMsgAsyncItemSaver *)
	?TextQueryL@MsgBioUtils@@SAXHAAVTDes16@@@Z @ 57 NONAME ; public: static void __cdecl MsgBioUtils::TextQueryL(int,class TDes16 &)
	?Value@CMsgNameValue@@QBEABVTDesC16@@XZ @ 58 NONAME ; public: class TDesC16 const & __thiscall CMsgNameValue::Value(void)const 
	?VirtualHeight@CMsgBioBodyControl@@UAEHXZ @ 59 NONAME ; public: virtual int __thiscall CMsgBioBodyControl::VirtualHeight(void)
	?VirtualHeight@CMsgBioControl@@UAEHXZ @ 60 NONAME ; public: virtual int __thiscall CMsgBioControl::VirtualHeight(void)
	?VirtualVisibleTop@CMsgBioBodyControl@@UAEHXZ @ 61 NONAME ; public: virtual int __thiscall CMsgBioBodyControl::VirtualVisibleTop(void)
	?VirtualVisibleTop@CMsgBioControl@@UAEHXZ @ 62 NONAME ; public: virtual int __thiscall CMsgBioControl::VirtualVisibleTop(void)
	?ConfirmationQueryOkCancelL@MsgBioUtils@@SAHABVTDesC16@@@Z @ 63 NONAME ; public: static int __cdecl MsgBioUtils::ConfirmationQueryOkCancelL(class TDesC16 const &)
	?ConfirmationQueryOkCancelL@MsgBioUtils@@SAHH@Z @ 64 NONAME ; public: static int __cdecl MsgBioUtils::ConfirmationQueryOkCancelL(int)
	?GetBioControlHelpContext@CMsgBioControl@@QBEHAAVTCoeHelpContext@@@Z @ 65 NONAME ; public: int __thiscall CMsgBioControl::GetBioControlHelpContext(class TCoeHelpContext &)const 
	?SetExtension@CMsgBioControl@@IAEXPAVMMsgBioControlExtension@@@Z @ 66 NONAME ; protected: void __thiscall CMsgBioControl::SetExtension(class MMsgBioControlExtension *)
	?Continue@CMsgAsyncItemSaver@@QAEXXZ @ 67 NONAME ; public: void __thiscall CMsgAsyncItemSaver::Continue(void)
	?Pause@CMsgAsyncItemSaver@@QAEXH@Z @ 68 NONAME ; public: void __thiscall CMsgAsyncItemSaver::Pause(int)

